aboutsummaryrefslogtreecommitdiff
path: root/odb/oracle/statement.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'odb/oracle/statement.hxx')
-rw-r--r--odb/oracle/statement.hxx5
1 files changed, 3 insertions, 2 deletions
diff --git a/odb/oracle/statement.hxx b/odb/oracle/statement.hxx
index ed8f298..bedddbc 100644
--- a/odb/oracle/statement.hxx
+++ b/odb/oracle/statement.hxx
@@ -51,8 +51,9 @@ namespace odb
protected:
struct unbind
{
- oracle::bind* bind; // Corresponding bind entry.
- void* value; // Actual value passed to OCIBindByPos.
+ oracle::bind::buffer_type type; // Bind type.
+ oracle::bind* bind; // Corresponding bind entry.
+ void* value; // Actual value passed to OCIBindByPos.
};
// Bind parameters for this statement. This function must only